"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _query = require("./query");

var _queries = _interopRequireDefault(require("./queries"));

var _transform = require("./transform");

var _types = require("./types");

const packageName = 'gatsby-source-shopify-graphql';
const fetchTypes = [_types.types.customer, _types.types.order, _types.types.product];

exports.sourceNodes = async ({
  actions,
  reporter,
  createNodeId,
  createContentDigest
}, options) => {
  try {
    const {
      createNode
    } = actions;
    const {
      queries: queryOptions
    } = options;
    const transforms = (0, _transform.getTransforms)(createNodeId, createContentDigest);

    for (const type of fetchTypes) {
      if (!queryOptions || Boolean(queryOptions[type])) {
        reporter.info(`${packageName} fetching ${type}s`);
        const transform = transforms[type];
        const results = await (0, _query.createQuery)(_queries.default[type], _types.typeMappings[type], options, reporter);

        if (Array.isArray(results)) {
          reporter.info(`${packageName} fetched ${results.length} ${type}s`);
          results.forEach(result => createNode(transform(result)));
        } else {
          reporter.error(`${packageName} failed to fetch ${type}s`);
        }
      }
    }
  } catch (error) {
    reporter.panicOnBuild(error);
  }

  return;
};